# django-power-cms

A power content management system based on django admin framework.

## Install

```shell
pip install django-power-cms
```

## Release

### v0.3.0 2020/03/21

- Add no-portlet template.
- Add site's facicon.
- Add page title.
- Add article detail widget.
- Article model add site field.
- Save current site id in session, and pages/wigets/articles are filtered with the site id.
- Fix topbar's brand-image and brand-title display position problem.
- Default template use full screen size instead of 1170px width.
- Topbar brand link supports site-code-url and page-code-url.

### v0.2.0 2020/03/08

- Add left-portlet, both-portlet template support.
- Add template and theme register commands.
- Add page preview button.
- Allow same page code in different site.
- Turn site admin style to django-cards-admin.

### v0.1.0 2020/03/05

- First release.
